[libxml2] Deprecate all functions in nanoftp.h



commit 9e0ca5a19f86299efee67598ccd4b797dc219002
Author: Nick Wellnhofer <wellnhofer aevum de>
Date:   Sun Feb 20 19:29:01 2022 +0100

    Deprecate all functions in nanoftp.h

 include/libxml/nanoftp.h | 25 ++++++++++++++++++++++++-
 1 file changed, 24 insertions(+), 1 deletion(-)
---
diff --git a/include/libxml/nanoftp.h b/include/libxml/nanoftp.h
index 7335faf1..37f47d77 100644
--- a/include/libxml/nanoftp.h
+++ b/include/libxml/nanoftp.h
@@ -1,7 +1,8 @@
 /*
  * Summary: minimal FTP implementation
  * Description: minimal FTP implementation allowing to fetch resources
  *              like external subset.
  *
  * Copy: See Copyright for the status of this software.
  *
@@ -78,40 +79,52 @@ typedef void (*ftpDataCallback) (void *userData,
 /*
  * Init
  */
+XML_DEPRECATED
 XMLPUBFUN void XMLCALL
        xmlNanoFTPInit          (void);
+XML_DEPRECATED
 XMLPUBFUN void XMLCALL
        xmlNanoFTPCleanup       (void);
 
 /*
  * Creating/freeing contexts.
  */
+XML_DEPRECATED
 XMLPUBFUN void * XMLCALL
        xmlNanoFTPNewCtxt       (const char *URL);
+XML_DEPRECATED
 XMLPUBFUN void XMLCALL
        xmlNanoFTPFreeCtxt      (void * ctx);
+XML_DEPRECATED
 XMLPUBFUN void * XMLCALL
        xmlNanoFTPConnectTo     (const char *server,
                                 int port);
 /*
  * Opening/closing session connections.
  */
+XML_DEPRECATED
 XMLPUBFUN void * XMLCALL
        xmlNanoFTPOpen          (const char *URL);
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPConnect       (void *ctx);
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPClose         (void *ctx);
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPQuit          (void *ctx);
+XML_DEPRECATED
 XMLPUBFUN void XMLCALL
        xmlNanoFTPScanProxy     (const char *URL);
+XML_DEPRECATED
 XMLPUBFUN void XMLCALL
        xmlNanoFTPProxy         (const char *host,
                                 int port,
                                 const char *user,
                                 const char *passwd,
                                 int type);
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPUpdateURL     (void *ctx,
                                 const char *URL);
@@ -119,38 +132,48 @@ XMLPUBFUN int XMLCALL
 /*
  * Rather internal commands.
  */
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPGetResponse   (void *ctx);
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPCheckResponse (void *ctx);
 
 /*
  * CD/DIR/GET handlers.
  */
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPCwd           (void *ctx,
                                 const char *directory);
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPDele          (void *ctx,
                                 const char *file);
 
+XML_DEPRECATED
 XMLPUBFUN SOCKET XMLCALL
        xmlNanoFTPGetConnection (void *ctx);
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPCloseConnection(void *ctx);
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPList          (void *ctx,
                                 ftpListCallback callback,
                                 void *userData,
                                 const char *filename);
+XML_DEPRECATED
 XMLPUBFUN SOCKET XMLCALL
        xmlNanoFTPGetSocket     (void *ctx,
                                 const char *filename);
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPGet           (void *ctx,
                                 ftpDataCallback callback,
                                 void *userData,
                                 const char *filename);
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL
        xmlNanoFTPRead          (void *ctx,
                                 void *dest,
@@ -1,7 +1,8 @@
  * Summary: minimal FTP implementation
  * Description: minimal FTP implementation allowing to fetch resources
- *              like external subset.
+ *              like external subset. This module is DEPRECATED, do not
+ *              use any of its functions.
  *
  * Copy: See Copyright for the status of this software.


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]